@@ -386,7 +386,7 @@ def cumulate(df, cumvars, method, periodvar='Date',  byvars=None, time=None, gro
     
     return outdf.drop(drop_cols, axis=1)
 
-def long_to_wide(df, groupvars, values, colindex=None):
+def long_to_wide(df, groupvars, values, colindex=None, colindex_only=False):
     '''
     
     groupvars = string or list of variables which signify unique observations in the output dataset
@@ -395,6 +395,10 @@ def long_to_wide(df, groupvars, values, colindex=None):
                in the output dataset. If not specified, just uses the
                count of the row within the group. If a list is provided, each column value will be appended
                in order separated by _
+    colindex_only = boolean. If true, column names in output data will be only the colindex, and will not
+                    include the name of the values variable. Only valid when passing a single value, otherwise
+                    multiple columns would have the same name.
+
     
     NOTE: Don't have any variables named key or idx
     
@@ -428,6 +432,9 @@ def long_to_wide(df, groupvars, values, colindex=None):
     if isinstance(values,str):
         values = [values]
     assert isinstance(values, list)
+
+    if colindex_only and len(values) > 1:
+        raise NotImplementedError('set colindex_only to False when passing more than one value')
     
     #Fixes for colindex
     #Use count of the row within the group for column index if not specified
@@ -454,7 +461,12 @@ def long_to_wide(df, groupvars, values, colindex=None):
             combined = df.copy()
         #Create wide dataset
         raw_wide = df.pivot(index='__key__', columns=colindex, values=value)
-        raw_wide.columns = [value + str(col) for col in raw_wide.columns]
+        if not colindex_only:
+            # add value name
+            raw_wide.columns = [value + str(col) for col in raw_wide.columns]
+        else:
+            # remove _ from colindex name
+            raw_wide.columns = [str(col).strip('_') for col in raw_wide.columns]
         wide = raw_wide.reset_index()
 
         #Merge back to original dataset
@@ -462,7 +474,18 @@ def long_to_wide(df, groupvars, values, colindex=None):
     
     return combined.drop([colindex,'__key__'] + values, axis=1).drop_duplicates().reset_index(drop=True)
 
-def load_sas(filepath, csv=True, **read_csv_kwargs):  
+def load_sas(filepath, csv=True, **read_csv_kwargs):
+    """
+    Loads sas sas7bdat file into a pandas DataFrame.
+
+    :param filepath: str of location of sas7bdat file
+    :param csv: when set to True, saves a csv version of the data in the same directory as the sas7bdat.
+                Next time load_sas will load from the csv version rather than sas7bdat, which speeds up
+                load times about 3x. If the sas7bdat file is modified more recently than the csv,
+                the sas7bdat will automatically be loaded and saved to the csv again.
+    :param read_csv_kwargs: kwargs to pass to pd.read_csv if csv option is True
+    :return:
+    """
     sas_name = os.path.basename(filepath) #e.g. dsename.sas7bdat
     folder = os.path.dirname(filepath) #location of sas file
     filename, extension = os.path.splitext(sas_name) #returns ('dsenames','.sas7bdat')
@@ -499,6 +522,7 @@ def averages(df, avgvars, byvars, wtvar=None, count=False, flatten=True):
     if isinstance(avgvars, str): avgvars = [avgvars]
     else:
         assert isinstance(avgvars, list)
+        avgvars = avgvars.copy() # don't modify existing avgvars inplace
     assert isinstance(byvars, (str, list))
     if wtvar != None:
         assert isinstance(wtvar, str)
@@ -761,6 +785,25 @@ class USTradingCalendar(AbstractHolidayCalendar):
     ]
         
 def tradedays():
+    """
+    Used for constructing a range of dates with pandas date_range function.
+
+    :Example:
+
+    >>>import pandas as pd
+    >>>pd.date_range(
+    >>>    start='1/1/2000',
+    >>>    end='1/31/2000',
+    >>>    freq=dero.pandas.tradedays()
+    >>>)
+    pd.DatetimeIndex(['2000-01-03', '2000-01-04', '2000-01-05', '2000-01-06',
+               '2000-01-07', '2000-01-10', '2000-01-11', '2000-01-12',
+               '2000-01-13', '2000-01-14', '2000-01-18', '2000-01-19',
+               '2000-01-20', '2000-01-21', '2000-01-24', '2000-01-25',
+               '2000-01-26', '2000-01-27', '2000-01-28', '2000-01-31'],
+              dtype='datetime64[ns]', freq='C')
+
+    """
     trading_calendar = USTradingCalendar()
     return CustomBusinessDay(holidays=trading_calendar.holidays())
 
@@ -1072,10 +1115,11 @@ def apply_func_to_unique_and_merge(series, func):
     seres: pd.Series
     func: function to be applied to the series.
     
-    Usage:
-    import functools
-    to_datetime = functools.partial(pd.to_datetime, format='%Y%m')
-    apply_func_to_unique_and_merge(df['MONTH'], to_datetime)
+    :Usage:
+
+    >>>import functools
+    >>>to_datetime = functools.partial(pd.to_datetime, format='%Y%m')
+    >>>apply_func_to_unique_and_merge(df['MONTH'], to_datetime)
     """
 
     unique = pd.Series(series.dropna().unique())
@@ -1158,8 +1202,8 @@ def _left_merge_latest_pandas(df, df2, on, left_datevar='Date', right_datevar='D
     lt = many.loc[many[left_datevar] >= many[right_datevar]] #left with datadates less than date
 
     #find rows within groups which have the maximum right_datevar (soonest before left_datevar)
-    data_rows = lt.groupby(on + [left_datevar], as_index=False)[right_datevar].max() \
-        .merge(lt, on=on + [left_datevar, right_datevar], how='left')
+    data_rows = lt.groupby(on + [left_datevar])[right_datevar].max() \
+        .reset_index().merge(lt, on=on + [left_datevar, right_datevar], how='left')
         
     if rename: #remove the _x for final merge
         data_rows.rename(columns={left_datevar: orig_left_datevar}, inplace=True)
