@@ -7,8 +7,6 @@ def _max_len_or_zero(iterable: Iterable) -> int:
     except ValueError:
         return 0
 
-def show_contents(obj):
-    print(_readable_repr(repr(obj)))
 
 def _readable_repr(repr_str):
     out_letters = []
