@@ -3,4 +3,4 @@ from dero.latex.table.models.data.table import DataTable
 from dero.latex.table.models.labels.table import LabelCollection, LabelTable
 from dero.latex.table.models.labels.label import Label
 from dero.latex.table.models.table.table import Table
-from dero.latex.logic.tools import show_contents
\ No newline at end of file
+from dero.mixins.repr import show_contents
\ No newline at end of file
