@@ -1,9 +1,22 @@
-from dero.latex.models.mixins import ReprMixin
+from dero.mixins.repr import ReprMixin
 from dero.latex.table.models.mixins.addvalues.row import RowAddMixin
 from dero.latex.table.models.labels.multicolumn import MultiColumn
+from dero.latex.texgen import general_latex_replacements
 
 
 class Label(ReprMixin, RowAddMixin):
+    """
+    Only necessary to use if need to set span or alignment manually. Can construct LabelCollection objects from Labels.
+
+    Useful for constructing custom multicolumn labels.
+
+    >>>import dero.latex.table as lt
+    >>>data_table = lt.DataTable.from_df(some_df)
+    >>>label = lt.Label('Long label', span=5, align='r')
+    >>>long_label_collection = lt.LabelCollection([label], underline='1-5')
+    >>>
+    >>>data_table.column_labels.insert(long_label_collection, 0)
+    """
     repr_cols = ['value', 'span']
 
     def __init__(self, value, span: int=1, align='c'):
@@ -18,10 +31,11 @@ class Label(ReprMixin, RowAddMixin):
             return self.value == other
 
     def __str__(self):
+        latex_valid_value = general_latex_replacements(str(self.value))
         if len(self) == 1:
-            return str(self.value)
+            return str(latex_valid_value)
         else:
-            return str(MultiColumn(self.value, span=self.span, align=self.align))
+            return str(MultiColumn(latex_valid_value, span=self.span, align=self.align))
 
     def __len__(self):
         return self.span
