@@ -1,4 +1,7 @@
 import statsmodels.api as sm
+from linearmodels import FamaMacBeth
+
+from dero.reg.linmodels.bindings.modelstr import _is_fama_macbeth_str
 
 
 def get_model_class_by_string(model_string):
@@ -8,6 +11,8 @@ def get_model_class_by_string(model_string):
         return sm.Probit
     elif _is_ols_str(model_string):
         return sm.OLS
+    elif _is_fama_macbeth_str(model_string):
+        return FamaMacBeth
     else:
         raise ValueError(f'model string does not signify ols, probit, or logit. got {model_string}')
 
@@ -19,4 +24,5 @@ def _is_logit_str(model_string):
     return model_string.lower().strip() in ('logit','l','log','lgt')
 
 def _is_ols_str(model_string):
-    return model_string.lower().strip() in ('ols','o','reg','least squares', 'ordinary least squares')
\ No newline at end of file
+    return model_string.lower().strip() in ('ols','o','reg','least squares', 'ordinary least squares')
+
